@@ -1,13 +1,19 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
-from atexit import register as atexit_register
-from os import makedirs
-from os import path
-from shutil import rmtree
-from sys import exit,  stderr
-from json import dumps
 import traceback
+from atexit import register as atexit_register
+from json import dumps
+from os import makedirs, path
+from shutil import rmtree
+from sys import exit, stderr
+
+try:
+    from loguru import logger
+    catch = logger.catch
+except ImportError:
+    def catch(x):
+        print('Setup in progress?')
 
 try:
     from .cli import Cli
@@ -18,7 +24,6 @@ try:
 except ImportError:
     print('Setup in progress?', file=stderr)
 
-
 __author__ = 'Sergey Zharkov'
 __license__ = 'MIT'
 __email__ = 'sttv-pc@mail.ru'
@@ -64,7 +69,7 @@ def _run_util(args) -> tuple:
 
 def _update_all(args):
     parse_args = args.parse_args()
-    print('Update all', file=stderr)
+    parse_args.quiet or print('Update all', file=stderr)
     multi_info = {}
 
     dst = parse_args.destination
@@ -75,9 +80,10 @@ def _update_all(args):
         parse_args.url = i['url']
         code, _info = _run_util(args)
         multi_info[i['directory']] = _info
-    parse_args.print_json and print(multi_info)
+    parse_args.quiet or (parse_args.print_json and print(multi_info))
 
 
+@catch
 def main():
     # if ~__version__.find('alpha'):
     #     print('Alpha release! There may be errors!', file=stderr)
@@ -88,7 +94,7 @@ def main():
     parse_args = args.parse_args()
 
     code, _info = _run_util(args)
-    parse_args.print_json and print(_info)
+    parse_args.quiet or (parse_args.print_json and print(_info))
 
     exit(code)
 
