@@ -1,11 +1,9 @@
+from os import path
 from zipfile import ZipFile, ZIP_DEFLATED
 
+from manga_py.fs import is_file, make_dirs, basename, dirname, unlink, get_temp_path
 # from PIL import Image as PilImage
 from manga_py.image import Image
-from os import path
-from time import sleep
-
-from manga_py.fs import is_file, make_dirs, basename, dirname, unlink, get_temp_path
 
 
 class Archive:
@@ -14,6 +12,7 @@ class Archive:
     files = None
     not_change_files_extension = False
     no_webp = False
+    has_error = False
 
     def __init__(self):
         self.files = []
@@ -42,6 +41,8 @@ class Archive:
                     jpeg_path = path.join(dirname(file[0]), jpeg)
                     Image(file[0]).convert(jpeg_path)
                     file = jpeg_path, jpeg
+                elif ext:
+                    file = file[0], ext
                 self._archive.write(*file)
 
     def __add_writes(self):
