@@ -2,6 +2,7 @@ import re
 from os import path
 from sys import stderr
 
+from loguru import logger
 from lxml.html import HtmlElement
 
 from manga_py.http import Http
@@ -125,6 +126,8 @@ class Base:
             for i in chapters:
                 url = self.__normalize_chapters(n, i)
                 items.append(url)
+        else:
+            logger.warning('Chapters list empty. Check %s' % self.get_url())
         return items
 
     @property
