@@ -1,7 +1,9 @@
 from argparse import ArgumentParser
 
-from .providers import get_provider
+from loguru import logger
+
 from .info import Info
+from .providers import get_provider
 
 
 class Parser:
@@ -33,10 +35,11 @@ class Parser:
             raise AttributeError('Provider not found')
         self.provider = provider(info)  # provider __init__
 
-        self.provider.set_progress_callback(progress)
+        self.provider.set_progress_callback(None if self.params['quiet'] else progress)
         self.provider.set_log_callback(log)
         self.provider.set_quest_callback(quest)
         self.provider.set_quest_password_callback(quest_password)
 
+    @logger.catch
     def start(self):
         self.provider.process(self.params['url'], self.params)
