@@ -1,7 +1,7 @@
 import json
 import re
-from abc import ABCMeta
-from sys import stderr, exit
+from abc import ABC
+from sys import stderr
 
 from .base_classes import (
     Abstract,
@@ -22,12 +22,12 @@ from .fs import (
     file_size,
 )
 from .http import MultiThreads
+from .info import Info
 from .meta import __downloader_uri__
 from .meta import __version__
-from .info import Info
 
 
-class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
+class Provider(Base, Abstract, Static, Callbacks, ABC):
     _volumes_count = 0
     _archive = None
     _zero_fill = False
@@ -35,6 +35,8 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
     _info = None
     _simulate = False
     _volume = None
+    _show_chapter_info = False
+    __debug = False
 
     def __init__(self, info: Info = None):
         super().__init__()
@@ -59,6 +61,8 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         self._zero_fill = params.get('zero_fill')
         self._with_manga_name = params.get('with_manga_name')
         self._simulate = params.get('simulate')
+        self._show_chapter_info = params.get('show_current_chapter_info', False)
+        self.__debug = params.get('debug', False)
 
     def process(self, url, params=None):  # Main method
         self._params['url'] = url
@@ -67,9 +71,16 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         for i in params:
             self._params.setdefault(i, params[i])
 
+        proxy = params.get('proxy', None)
+        if proxy is not None:
+            self._storage['proxies'] = {
+                'http': proxy,
+                'https': proxy,
+            }
+
         self.prepare_cookies()
         self._storage['manga_name'] = self.get_manga_name()
-        self._storage['main_content'] = self.get_main_content()
+        self._storage['main_content'] = self.content
         self._storage['chapters'] = self._prepare_chapters(self.get_chapters())
 
         if not self._params.get('reverse_downloading', False):
@@ -87,44 +98,46 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
 
         return not_allow_archive and is_file(_path)
 
-    def _download_chapter(self, idx, _min, _max):
-        if idx < _min or (idx >= _max > 0) or self._check_archive():
-            return
+    def _download_chapter(self):
         if not self._simulate:
             try:
                 self.before_download_chapter()
                 self._storage['files'] = self.get_files()
                 self.loop_files()
             except Exception as e:
-                print(e, file=stderr)
+                # Main debug here
+                if self.__debug:
+                    raise e
+                self.log([e], file=stderr)
                 self._info.set_last_volume_error(e)
 
     def loop_chapters(self):
         volumes = self._storage['chapters']
         _min = self._params.get('skip_volumes', 0)
         _max = self._params.get('max_volumes', 0)
-        if _max > 0 and _min > 0:
-            _max += _min - 1
+        count = 0  # count downloaded chapters
         for idx, __url in enumerate(volumes):
             self.chapter_id = idx
+            if idx < _min or (count >= _max > 0) or self._check_archive():
+                continue
+            count += 1
             self._info.add_volume(self.chapter_for_json(), self.get_archive_path())
-            self._download_chapter(idx, _min, _max)
+            self._download_chapter()
 
     def loop_files(self):
         if isinstance(self._storage['files'], list):
+            if self._show_chapter_info:
+                self.log('\n\nCurrent chapter url: %s\n' % (self.chapter,))
             if len(self._storage['files']) == 0:
-                print('Error processing file: %s' % self.get_archive_name(), file=stderr)
+                # see Std
+                self.log('Error processing file: %s' % self.get_archive_name(), file=stderr)
                 return
             self._archive = Archive()
             self._archive.not_change_files_extension = self._params.get('not_change_files_extension', False)
             self._archive.no_webp = self._image_params.get('no_webp', False)
             self._call_files_progress_callback()
 
-            if self._params.get('one_thread', False):
-                self._one_thread_save(self._storage['files'])
-
-            else:
-                self._multi_thread_save(self._storage['files'])
+            self._multi_thread_save(self._storage['files'])
 
             self.make_archive()
 
@@ -152,6 +165,7 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         return _path
 
     def get_archive_path(self):
+        # see Std
         _path = remove_file_query_params(self.get_archive_name())
         _path = self.remove_not_ascii(_path)
 
@@ -162,11 +176,21 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         if not len(name):
             name = self._storage['manga_name']
 
+        additional_data_name = ''
+        if self.http().has_error:
+            additional_data_name = 'ERROR.'
+            self.http().has_error = False
+
         return path_join(
             self._params.get('destination', 'Manga'),
             name,
-            _path + '.%s' % self._archive_type()
-        )
+            _path + '.%s%s' % (additional_data_name, self._archive_type())
+        ) \
+            .replace('?', '_') \
+            .replace('"', '_') \
+            .replace('>', '_') \
+            .replace('<', '_') \
+            .replace('|', '_')  # Windows...
 
     def make_archive(self):
         _path = self.get_archive_path()
@@ -183,8 +207,8 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         try:
             self._archive.make(_path)
         except OSError as e:
-            print('')
-            print(e)
+            self.log('')
+            self.log(e)
             self.log(e, file=stderr)
             self._info.set_last_volume_error(str(e))
             unlink(_path)
@@ -204,22 +228,13 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         threading = MultiThreads()
         # hack
         self._storage['current_file'] = 0
-        if self._params.get('no_multi_threads', False):
-            threading.threads = 2
+        if self._params.get('max_threads', None) is not None:
+            threading.max_threads = int(self._params.get('max_threads'))
         for idx, url in enumerate(files):
-            threading.add(self.save_file, (idx, self._multi_thread_callback, url))
+            threading.add(self.save_file, (idx, self._multi_thread_callback, url, None))
 
         threading.start()
 
-    def _one_thread_save(self, files):
-
-        for idx, __url in enumerate(files):
-            self._storage['current_file'] = idx
-            self._call_files_progress_callback()
-            self.save_file()
-        _max = len(self._storage['files'])
-        self.progress(_max, _max)
-
     def cf_protect(self, url):
         """
         WARNING! Thins function replace cookies!
@@ -242,3 +257,10 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         for k in cookies:
             self._storage['cookies'][k] = cookies[k]
             self.http().cookies[k] = cookies[k]
+
+    @property
+    def content(self):
+        content = self._storage.get('main_content', None)
+        if content is None:
+            content = self.get_main_content()
+        return content
