@@ -1,9 +1,16 @@
 import re
+import importlib
 
 providers_list = {
+    '1stkissmanga_com': [
+        r'1stkissmanga\.com/manga/.',
+    ],
     '3asq_info': [
         r'3asq\.info/.',
     ],
+    '7sama_com': [
+        r'7sama\.com/manga/.',
+    ],
     # '8muses_com': [
     #     r'8muses\.com/comics/album/.',
     # ],
@@ -34,9 +41,9 @@ providers_list = {
     'atfbooru_ninja': [
         r'atfbooru\.ninja/posts.',
     ],
-    'authrone_com': [
-        r'authrone\.com/manga/.',
-    ],
+    # 'authrone_com': [
+    #     r'authrone\.com/manga/.',
+    # ],
     'bato_to': [
         r'bato\.to/(series|chapter)/\d',
     ],
@@ -46,6 +53,9 @@ providers_list = {
     'bns_shounen_ai_net': [
         r'bns\.shounen-ai\.net/read/(series|read)/.',
     ],
+    'boredomsociety_xyz': [
+        r'boredomsociety\.xyz/(titles/info|reader)/\d',
+    ],
     'cdmnet_com_br': [
         r'cdmnet\.com\.br/titulos/.',
     ],
@@ -76,6 +86,9 @@ providers_list = {
     'comicvn_net': [
         r'comicvn\.net/truyen-tranh-online/.',
     ],
+    'cycomi_com': [
+        r'cycomi\.com/fw/cycomibrowser/chapter/title/\d',
+    ],
     'danbooru_donmai_us': [
         r'danbooru\.donmai\.us/posts.',
     ],
@@ -127,7 +140,7 @@ providers_list = {
         r'gomanga\.co/reader/.',
         r'jaiminisbox\.com/reader/.',
         r'kobato\.hologfx\.com/reader/.',
-        r'atelierdunoir\.org/reader/.',
+        # r'atelierdunoir\.org/reader/.',
         r'seinagi\.org/reader/.',
     ],
     'goodmanga_net': [
@@ -159,12 +172,18 @@ providers_list = {
     'hentai_image_com': [
         r'hentai-image\.com/image/.',
     ],
+    'hentaihand_com': [
+        r'hentaihand\.com/comic/\d',
+    ],
     'hentaifox_com': [
         r'hentaifox\.com/.',
     ],
     'hentaihere_com': [
         r'hentaihere\.com/m/.',
     ],
+    'hentaiporns_net': [
+        r'hentaiporns\.net/.'
+    ],
     'hentairead_com': [
         r'hentairead\.com/.',
     ],
@@ -199,8 +218,11 @@ providers_list = {
     'inmanga_com': [
         r'inmanga\.com/ver/manga/.',
     ],
+    'isekaiscan_com': [
+        r'isekaiscan\.com/manga/.',
+    ],
     'japscan_com': [
-        r'japscan\.cc/.',
+        r'japscan\.to/.',
     ],
     'jurnalu_ru': [
         r'jurnalu\.ru/online-reading/.',
@@ -217,8 +239,6 @@ providers_list = {
         r'mangaforest\.com/manga/.',
         r'mangadenizi\.com/.',
         r'mangadoor\.com/manga/.',
-        r'mangaid\.co/manga/.',
-        r'mangaid\.net/manga/.',
         r'manga\.fascans\.com/manga/.',
         r'mangadesu\.net/manga/.',
         r'mangahis\.com/manga/.',
@@ -229,7 +249,7 @@ providers_list = {
         r'manga-v2\.mangavadisi\.org/manga/.',
         r'universoyuri\.com/manga/.',
         r'digitalteam1\.altervista\.org/manga/.',
-        r'sosscanlation\.com/manga/.',
+        # r'sosscanlation\.com/manga/.',
         r'komikgue\.com/manga/.',
     ],
     'kumanga_com': [
@@ -244,6 +264,13 @@ providers_list = {
     'leomanga_com': [
         r'leomanga\.com/manga/.',
     ],
+    'leviatanscans_com': [
+        r'leviatanscans\.com/comics/\d'
+    ],
+    'lhtranslation_com': [
+        r'read\.lhtranslation\.com/(truyen|manga)-.',
+        r'lhtranslation\.net/(truyen|manga)-.',
+    ],
     'lolibooru_moe': [
         r'lolibooru\.moe/post.',
     ],
@@ -255,7 +282,7 @@ providers_list = {
         r'luscious\.net/albums/.',
     ],
     'mangapark_org': [
-        r'mangapark\.org/(series|chapter)/',   # is different!
+        r'mangapark\.org/(series|chapter)/',  # is different!
     ],
     'mang_as': [
         r'mang\.as/manga/.',
@@ -288,6 +315,9 @@ providers_list = {
     'manga_tr_com': [
         r'manga-tr\.com/(manga|id)-.',
     ],
+    'mangabat_com': [
+        r'mangabat\.com/(manga|chapter)/.',
+    ],
     'mangabb_co': [
         r'mangabb\.co/.',
     ],
@@ -313,26 +343,45 @@ providers_list = {
         r'mangadeep\.com/.',
         r'manga99\.com/.',
     ],
+    'mangadex_org': [
+        r'mangadex\.org/manga/.',
+    ],
     'mangadex_com': [
-        r'mangadex\.com/(manga|chapter)/.',
-        r'mangadex\.org/(manga|chapter)/.',
+        r'mangadex\.com/(title|chapter)/.',
+        r'mangadex\.org/(title|chapter)/.',
+    ],
+    'mangadex_info': [
+        r'mangadex\.info/manga/.',
     ],
     'mangaeden_com': [
         r'mangaeden\.com/[^/]+/[^/]+-manga/.',
         r'perveden\.com/[^/]+/[^/]+-manga/.',
     ],
-    'mangaforall_com': [
-        r'mangaforall\.com/m/.',
+    'mangafans_us': [  # MangaNeloCom
+        r'mangafans\.us/manga/.',
+        r'mangahot\.org/read-manga/.',
     ],
+    # 'mangaforall_com': [
+    #     r'mangaforall\.com/m/.',
+    # ],
     'mangafreak_net_download': [
         r'mangafreak\.net/Manga/.',
     ],
-    'mangago_me': [
-        r'mangago\.me/read-manga/.',
+    'mangafull_org': [
+        r'mangafull\.org/manga/.',
     ],
+    # 'mangago_me': [
+    #     r'mangago\.me/read-manga/.',
+    # ],
     'mangahasu_se': [
         r'mangahasu\.se/.',
     ],
+    'mangaheaven_club': [
+        r'mangaheaven\.club/read-manga/.',
+    ],
+    'mangaheaven_xyz': [
+        r'mangaheaven\.xyz/manga/.',
+    ],
     'mangahere_cc': [
         r'mangahere\.co/manga/.',
         r'mangahere\.cc/manga/.',
@@ -340,12 +389,17 @@ providers_list = {
     'mangahi_net': [
         r'mangahi\.net/.',
     ],
+    'mangaid_me': [
+        r'mangaid\.co/manga/.',
+        r'mangaid\.net/manga/.',
+        r'mangaid\.me/manga/.',
+    ],
     'mangahome_com': [
         r'mangahome\.com/manga/.',
     ],
     'mangahub_io': [
         r'mangahub\.io/(manga|chapter)/.',
-        r'mangareader\.site/(manga|chapter)/.',
+        # r'mangareader\.site/(manga|chapter)/.',
         r'mangakakalot\.fun/(manga|chapter)/.',
         r'mangahere\.onl/(manga|chapter)/.',
     ],
@@ -368,7 +422,8 @@ providers_list = {
         r'mangakatana\.com/manga/.',
     ],
     'mangaku_web_id': [
-        r'mangaku\.web\.id/.',
+        # r'mangaku\.web\.id/.',
+        r'mangaku\.in/.',
     ],
     'mangalib_me': [
         r'mangalib\.me/.',
@@ -383,7 +438,6 @@ providers_list = {
         r'mangamew\.com/(\w+-)?truyen/.',
     ],
     'manganelo_com': [
-        r'mangabat\.com/(manga|chapter)/.',
         r'manganelo\.com/(manga|chapter)/.',
     ],
     'mangaon_net': [
@@ -407,11 +461,14 @@ providers_list = {
     'mangareader_net': [
         r'mangareader\.net/.',
     ],
+    'mangareader_site': [
+        r'mangareader\.site',
+    ],
     'mangareader_xyz': [
         r'mangareader\.xyz/manga/.',
         r'mangareader\.xyz/.+?/chapter-\d',
-        r'mangafox\.cc/manga/.',
-        r'mangafox\.cc/.+?/chapter-\d',
+        # r'mangafox\.cc/manga/.',
+        # r'mangafox\.cc/.+?/chapter-\d',
     ],
     'mangarock_com': [
         r'mangarock\.com/manga/.',
@@ -431,6 +488,9 @@ providers_list = {
     'mangasupa_com': [
         r'mangasupa\.com/(manga|chapter)/.',
     ],
+    'mangasushi_net': [
+        r'mangasushi\.net/manga/.',
+    ],
     'mangatail_com': [
         r'mangasail\.com/(manga|chapter|node|content)/.',
         r'mangasail\.co/(manga|chapter|node|content)/.',
@@ -449,6 +509,11 @@ providers_list = {
     'mangax_net': [
         r'mangax\.net/\w/.',
     ],
+    'mangazuki_me': [
+        r'mangazuki\.me/manga/.',
+        r'mangazuki\.info/manga/.',
+        r'mangazuki\.online/manga/.',
+    ],
     'manhuagui_com': [
         r'manhuagui\.com/comic/\d',
     ],
@@ -458,8 +523,11 @@ providers_list = {
     'manhwa_co': [
         r'manhwa\.co/.',
     ],
+    # 'manhwahentai_com': [
+    #     r'manhwahentai\.com/manhwa/.'
+    # ],
     'merakiscans_com': [
-        r'merakiscans\.com/.',
+        r'merakiscans\.com/manga/.',
     ],
     'mintmanga_com': [
         r'mintmanga\.com/.',
@@ -489,6 +557,9 @@ providers_list = {
     'nightow_net': [
         r'nightow\.net/online/\?manga=.',
     ],
+    'nineanime_com': [
+        r'nineanime\.com/manga/.+\.html'
+    ],
     'ninemanga_com': [
         r'ninemanga\.com/(manga|chapter).',
         r'addfunny\.com/(manga|chapter).',
@@ -500,11 +571,15 @@ providers_list = {
         r'nozominofansub\.com/public(/index\.php)?/manga/.',
         r'godsrealmscan\.com/public(/index\.php)?/manga/.',
     ],
+    # 'nude_moon_me': [
+    #     r'nude-moon\.me/\d',
+    # ],
     'otakusmash_com': [
         r'otakusmash\.com/.',
         r'mrsmanga\.com/.',
         r'mentalmanga\.com/.',
         r'mangasmash\.com/.',
+        r'omgbeaupeep\.com/comics/.',
     ],
     'otscans_com': [
         r'otscans\.com/foolslide/(series|read)/.',
@@ -559,10 +634,9 @@ providers_list = {
     'read_powermanga_org': [
         r'lector\.dangolinenofansub\.com/(series|read)/.',
         r'read\.powermanga\.org/(series|read)/.',
-        r'read\.yagami\.me/(series|read)/.',
+        # r'read\.yagami\.me/(series|read)/.',
         r'reader\.kireicake\.com/(series|read)/.',
         r'reader\.shoujosense\.com/(series|read)/.',
-        r'reader\.sensescans\.com/(series|read)/.',
         r'reader\.whiteoutscans\.com/(series|read)/.',
         r'slide\.world-three\.org/(series|read)/.',
         r'manga\.animefrontline\.com/(series|read)/.',
@@ -585,13 +659,22 @@ providers_list = {
         r'digitalteamreader\.netsons\.org/(series|read)/.',
         r'reader\.manga-download\.org/(series|read)/.',
     ],
-    'readcomicbooksonline_org_manga': [
-        r'readcomicbooksonline\.net/manga/.',
-        r'readcomicbooksonline\.org/manga/.',
+    'read_yagami_me': [
+        r'read\.yagami\.me/series/\w',
     ],
-    'readcomicbooksonline_org': [
-        r'readcomicbooksonline\.net/.',
-        r'readcomicbooksonline\.org/.',
+    # 'readcomicbooksonline_org_manga': [  # todo #168
+    #     r'readcomicbooksonline\.net/manga/.',
+    #     r'readcomicbooksonline\.org/manga/.',
+    # ],
+    # 'readcomicbooksonline_org': [
+    #     r'readcomicbooksonline\.net/.',
+    #     r'readcomicbooksonline\.org/.',
+    # ],
+    'comicpunch_net_manga': [
+        r'comicpunch\.net/asiancomics/.',
+    ],
+    'comicpunch_net': [
+        r'comicpunch\.net/.',
     ],
     'reader_championscans_com': [
         r'reader\.championscans\.com/(series|read)/.',
@@ -599,12 +682,15 @@ providers_list = {
     'reader_imangascans_org': [
         r'reader\.imangascans\.org/.',
     ],
-    'readhentaimanga_com': [
-        r'readhentaimanga\.com/.',
-    ],
+    # 'readhentaimanga_com': [
+    #     r'readhentaimanga\.com/.',
+    # ],
     'readcomiconline_to': [
         r'readcomiconline\.to/Comic/.',
     ],
+    'readcomicsonline_ru': [
+        r'readcomicsonline\.ru/comic/.',
+    ],
     'readmanga_me': [
         r'readmanga\.me/.',
     ],
@@ -642,13 +728,16 @@ providers_list = {
     'siberowl_com': [
         r'siberowl\.com/mangas/.',
     ],
-    'somanga_net': [
-        r'somanga\.net/(leitor|manga)/.',
-        r'somangas\.net/(leitor|manga)/.',
+    'sleepypandascans_co': [
+        r'sleepypandascans\.co/(Series|Reader)/.',
     ],
+    #'somanga_net': [
+    #    r'somanga\.net/(leitor|manga)/.',
+    #    r'somangas\.net/(leitor|manga)/.',
+    #],
     'subapics_com': [
-        r'subapics\.com/manga/.',
-        r'subapics\.com/.+-chapter-.',
+        # r'subapics\.com/manga/.',
+        # r'subapics\.com/.+-chapter-.',
         r'mangakita\.net/manga/.',
         r'mangakita\.net/.+-chapter-.',
         r'komikstation\.com/manga/.',
@@ -674,6 +763,9 @@ providers_list = {
     'tenmanga_com': [
         r'tenmanga\.com/(book|chapter)/.',
     ],
+    'tmofans_com': [
+        r'tmofans\.com/library/manga/\d',
+    ],
     'translate_webtoons_com': [
         r'translate\.webtoons\.com/webtoonVersion\?webtoonNo.',
     ],
@@ -687,6 +779,7 @@ providers_list = {
         r'toonkor\.co/.',
     ],
     'triplesevenscans_com': [
+        r'sensescans\.com/reader/(series|read)/.',
         r'triplesevenscans\.com/reader/(series|read)/.',
         r'cm-scans\.shounen-ai\.net/reader/(series|read)/.',
         r'yaoislife\.shounen-ai\.net/reader/(series|read)/.',
@@ -706,16 +799,18 @@ providers_list = {
         r'tsumino\.com/Book/Info/\d',
         r'tsumino\.com/Read/View/\d',
     ],
-    'tumangaonline_com': [
-        r'tumangaonline\.com/.',
-        r'tumangaonline\.me/.',
-    ],
+    # 'tumangaonline_com': [
+    #     r'tumangaonline\.com/.',
+    #     r'tumangaonline\.me/.',
+    # ],
     'unionmangas_net': [
         r'unionmangas\.cc/(leitor|manga)/.',
         r'unionmangas\.net/(leitor|manga)/.',
         r'unionmangas\.site/(leitor|manga)/.',
     ],
-    # 'viz_com': [r'viz\.com/shonenjump/chapters/.',],
+    'viz_com': [
+        r'viz\.com/shonenjump/chapters/.',
+    ],
     'web_ace_jp': [
         r'web-ace\.jp/youngaceup/contents/\d',
     ],
@@ -746,6 +841,7 @@ providers_list = {
     ],
     'zeroscans_com': [
         r'zeroscans\.com/manga/.',
+        r'manhwareader\.com/manga/.',
     ],
     'zingbox_me': [
         r'zingbox\.me/.',
@@ -769,6 +865,6 @@ def get_provider(url):
     fromlist = 'manga_py.providers'
     for i in providers_list:
         if __check_provider(providers_list[i], url):
-            provider = __import__('{}.{}'.format(fromlist, i), fromlist=[fromlist])
+            provider = importlib.import_module('%s.%s' % (fromlist, i))
             return provider.main
     return False
