@@ -28,9 +28,8 @@ class FunMangaCom(Provider, Std):
     def get_cover(self):
         return self._cover_from_content('img.img-responsive.mobile-img')
 
-    def book_meta(self) -> dict:
-        # todo meta
-        pass
+    def prepare_cookies(self):
+        self.cf_protect(self.get_url())
 
 
 main = FunMangaCom
