@@ -6,11 +6,12 @@ class GoMangaCo(Provider, Std):
     _name_re = '/reader/[^/]+/([^/]+)/'
     _content_str = '{}/reader/series/{}/'
     _chapters_selector = '.list .element .title a'
+    _chapter_re = r'/rea\w+/[^/]+/[^/]+/(?:[^/]+/)?(\d+/\d+(?:/\d+)?)'
+
+    _go_chapter_content = ''
 
     def get_chapter_index(self) -> str:
-        url = self.chapter
-        index_re = r'/rea\w+/[^/]+/[^/]+/(?:[^/]+/)?(\d+/\d+(?:/\d+)?)'
-        group = self.re.search(index_re, url).group(1)
+        group = self.re.search(self._chapter_re, self.chapter).group(1)
         return group.replace('/', '-')
 
     def get_main_content(self):
@@ -27,9 +28,9 @@ class GoMangaCo(Provider, Std):
         return r'var\s{}\s*=\s*(\[.+\])'.format(idx)
 
     def get_files(self):
-        content = self.http_get(self.chapter)
-        selector = self._get_json_selector(content)
-        items = self.json.loads(self.re.search(selector, content).group(1))
+        self._go_chapter_content = self.http_get(self.chapter)
+        selector = self._get_json_selector(self._go_chapter_content)
+        items = self.json.loads(self.re.search(selector, self._go_chapter_content).group(1))
         return [i.get('url') for i in items]
 
     def get_cover(self) -> str:
