@@ -1,9 +1,14 @@
-from ._http2 import Http2
+from requests import get
+from time import sleep
 
 
 class Std:
+    _vol_fill = False
+
     def get_archive_name(self) -> str:
-        return self.normal_arc_name({'vol': self.get_chapter_index().split('-')})
+        idx = self.get_chapter_index()
+        self._vol_fill = True
+        return self.normal_arc_name({'vol': idx.split('-')})
 
     def _elements(self, selector, content=None) -> list:
         if not content:
@@ -50,8 +55,8 @@ class Std:
             url = self.get_url()
         return self.re.search(selector, url).group(1)
 
-    def _get_content(self, selector) -> str:
-        return self.http_get(selector.format(self.domain, self.manga_name))
+    def _get_content(self, tpl) -> str:
+        return self.http_get(tpl.format(self.domain, self.manga_name))
 
     def _base_cookies(self, url=None):
         if url is None:
@@ -64,13 +69,6 @@ class Std:
         url = self.re.search(selector, image.get('style'))
         return self.http().normalize_uri(url.group(1))
 
-    @property
-    def content(self):
-        content = self._storage.get('main_content', None)
-        if content is None:
-            content = self.get_main_content()
-        return content
-
     @property
     def manga_name(self) -> str:
         name = self._storage.get('manga_name', None)
@@ -82,6 +80,7 @@ class Std:
         if isinstance(idx, str):
             idx = [idx]
         if isinstance(idx, list):
+            self._vol_fill = True
             return self.__normal_name_list(idx)
         if isinstance(idx, dict):
             return self.__normal_name_dict(idx)
@@ -89,28 +88,29 @@ class Std:
 
     @staticmethod
     def __fill(var, fmt: str = '-{}'):
-        if len(var) > 1:
-            var = (fmt * len(var)).format(*var)
-        return var
+        if isinstance(var, str):
+            var = [var]
+        return (fmt * len(var)).format(*var).lstrip('-')
 
     def __normal_name_list(self, idx: list):
         fmt = 'vol_{:0>3}'
         if len(idx) > 1:
             fmt += '-{}' * (len(idx) - 1)
-        elif self._zero_fill:
+        elif self._vol_fill and self._zero_fill:
             idx.append('0')
             fmt += '-{}'
         return fmt.format(*idx)
 
     def __normal_name_dict(self, idx: dict):
-        vol = idx.get('vol', '0')
+        vol = idx.get('vol', None)
         ch = idx.get('ch', None)
-        fmt = 'vol{}'
-        data = [self.__fill(vol, '-{:0>3}')]
+        result = ''
+        if vol:
+            if isinstance(vol, str):
+                vol = [vol]
+            result = self.__normal_name_list(vol)
         if ch:
-            fmt += '-ch{}'
-            data.append(self.__fill(ch))
-        result = fmt.format(*data)
+            result += '-ch_' + self.__fill(ch)
         if self._with_manga_name:
             result = '%s-%s' % (self.manga_name, result)
         return result
@@ -123,3 +123,22 @@ class Std:
         if strip:
             text = text.strip()
         return text
+
+    def _download(self, file_name, url, method):
+        # clean file downloader
+        now_try_count = 0
+        while now_try_count < 5:
+            with open(file_name, 'wb') as out_file:
+                now_try_count += 1
+                response = get(url, timeout=60, allow_redirects=True)
+                if response.status_code >= 400:
+                    self.http().debug and self.log('ERROR! Code {}\nUrl: {}'.format(
+                        response.status_code,
+                        url,
+                    ))
+                    sleep(2)
+                    continue
+                out_file.write(response.content)
+                response.close()
+                out_file.close()
+                break
