@@ -1,10 +1,9 @@
+from sys import stderr
+
 from manga_py.crypt import KissMangaComCrypt
-from manga_py.fs import basename
 from manga_py.provider import Provider
 from .helpers.std import Std
 
-from sys import stderr
-
 
 class KissMangaCom(Provider, Std):
     __local_data = {
@@ -13,25 +12,14 @@ class KissMangaCom(Provider, Std):
     }
 
     def get_archive_name(self) -> str:
-        idx = self.get_chapter_index()
-        return 'Ch-{:0>3}_Vol-{:0>3}-{:0>1}'.format(*idx.split('-'))
+        return '{:0>3}-{}'.format(
+            self.chapter_id + 1,
+            self.get_chapter_index()
+        )
 
     def get_chapter_index(self) -> str:
-        bn = basename(self.chapter)
-        name = self.re.search(r'Vol-+(\d+)-+Ch\w*?-+(\d+)-+(\d+)', bn)
-        if name:
-            name = name.groups()
-            return '{1}-{0}-{2}'.format(*name)
-        name = self.re.search(r'Vol-+(\d+)-+Ch\w*?-+(\d+)', bn)
-        if name:
-            name = name.groups()
-            return '{1}-{0}-0'.format(*name)
-        name = self.re.search(r'Ch\w*?-(\d+)(?:-v(\d+))?', bn)
-        if name:
-            name = name.groups()
-            return '{}-{}-0'.format(*name, '0')
-        name = self.re.search(r'/Manga/[^/]+/(\d+)', self.chapter)
-        return '{}-000-0'.format(name.group(1))
+        name = self.re.search(r'/Manga/[^/]+/(.+)\?id=(\d+)', self.chapter)
+        return '-'.join(name.groups())
 
     def get_main_content(self):
         return self._get_content('{}/Manga/{}')
@@ -42,7 +30,7 @@ class KissMangaCom(Provider, Std):
     def get_chapters(self):
         chapters = self._elements('.listing td a')
         if not len(chapters):
-            print('Chapters not found', file=stderr)
+            self.log('Chapters not found', file=stderr)
         return chapters
 
     def prepare_cookies(self):
@@ -50,7 +38,7 @@ class KissMangaCom(Provider, Std):
         self.cf_protect(self.get_url())
         self._storage['cookies']['rco_quality'] = 'hq'
         if not self._params['cf-protect']:
-            print('CloudFlare protect fail!', file=stderr)
+            self.log('CloudFlare protect fail!', file=stderr)
 
     def __decrypt_images(self, crypt, key, hexes):
         images = []
@@ -84,9 +72,8 @@ class KissMangaCom(Provider, Std):
         key = self.__check_key(crypt, content)
         hexes = self.re.findall(r'lstImages.push\(wrapKA\(["\']([^"\']+?)["\']\)', content)
         if not hexes:
-            print('Images not found!', file=stderr)
+            self.log('Images not found!', file=stderr)
             return []
-        self._storage['referer'] = self.http().referer = ''
         return self.__decrypt_images(crypt, key, hexes)
 
     def get_cover(self):
