@@ -14,19 +14,19 @@ class MangaHubRu(Provider, Std):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
-        return self.re.search(r'\.ru/([^/]+)/?', self.get_url())
+        return self._get_name(r'\.ru/([^/]+)/?')
 
     def get_chapters(self):
-        return self.document_fromstring(self.content, '.b-catalog-list__name a[href^="/"]')
+        return self._elements('.b-catalog-list__name a[href^="/"]')
 
     def get_files(self):
         parser = self.html_fromstring(self.chapter, '.b-main-container .b-reader__full')
         if not parser:
             return []
         result = parser[0].get('data-js-scans')
-        result = self.json.loads(html.unescape(result.replace('\/', '/')))
-        domain = self.domain
-        return [domain + i['src'] for i in result]
+        result = self.json.loads(html.unescape(result.replace(r'\/', '/')))
+        n = self.http().normalize_uri
+        return [n(i['src']) for i in result]
 
     def get_cover(self):
         return self._cover_from_content('.manga-section-image__img img')
