@@ -3,13 +3,15 @@ from .helpers.std import Std
 
 
 class MangaNeloCom(Provider, Std):
+    chapter_re = r'[/-]chap(?:ter)?[_-](\d+(?:\.\d+)?)'
+    _prefix = '/manga/'
 
     def get_chapter_index(self) -> str:
-        re = self.re.compile(r'/chapter_(\d+(?:\.\d+)?)')
-        return re.search(self.chapter).group(1).replace('.', '-')
+        return self.re.search(self.chapter_re, self.get_chapter())\
+            .group(1).replace('.', '-')
 
     def get_main_content(self):
-        return self._get_content('{}/manga/{}')
+        return self._get_content('{}%s{}' % self._prefix)
 
     def get_manga_name(self) -> str:
         return self._get_name('/(?:manga|chapter)/([^/]+)')
@@ -18,18 +20,17 @@ class MangaNeloCom(Provider, Std):
         return self._elements('.chapter-list a')
 
     def get_files(self):
-        parser = self.html_fromstring(self.chapter)
+        parser = self.html_fromstring(self.get_chapter())
         images = self._images_helper(parser, '#vungdoc img')
         if not len(images):
-            images = self._images_helper(parser, '.vung_doc img')
+            images = self._images_helper(parser, '.vung_doc img,.vung-doc img')
         return images
 
     def get_cover(self) -> str:
         return self._cover_from_content('.manga-info-pic img')
 
-    def book_meta(self) -> dict:
-        # todo meta
-        pass
+    def get_chapter(self):
+        return self.chapter
 
 
 main = MangaNeloCom
