@@ -7,10 +7,6 @@ class MangaShiroNet(Provider, Std):
     chapter_re = r'\.net/[^/]+-(\d+(?:-\d+)?)'
     chapters_selector = 'span.leftoff > a'
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         chapter = self.chapter
         return self.re.search(self.chapter_re, chapter).group(1)
