@@ -5,10 +5,6 @@ from .helpers.std import Std
 class RawDevArtCom(Provider, Std):
     _chapter_selector = r'/chapter/[^\d]+(\d+(?:\.\d+)?)'
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-')
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         idx = self.re.search(self._chapter_selector, self.chapter)
         return '-'.join(idx.group(1).split('.'))
