@@ -4,10 +4,6 @@ from .helpers.std import Std
 
 class ShakaiRu(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        idx = self.get_chapter_index().split('-', 2)
-        return self.normal_arc_name(idx)
-
     def get_chapter_index(self) -> str:
         idx = self.chapter.get('data-first')
         return idx.replace('_', '-')
