@@ -5,9 +5,6 @@ from .helpers.std import Std
 class ZMangaNet(Provider, Std):
     _type = 'capitulo'
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index())
-
     def get_chapter_index(self) -> str:
         re = self.re.compile(r'%s-(\d+(?:-\d+)?)' % self._type)
         return re.search(self.chapter).group(1)
